pub struct TableMutationNotification {
pub affected_tables: HashSet<String>,
}Expand description
Notification sent when a mutation affects tables This is broadcast to all connections so they can notify their subscriptions
Fields
affected_tables: HashSet<String>Tables that were affected by the mutation