pub struct PartialRowDelta {
pub column_indices: Vec<usize>,
pub old_values: Vec<SqlValue>,
pub new_values: Vec<SqlValue>,
}Expand description
A partial row update containing only changed columns plus primary key columns
Used for efficient updates when only a subset of columns have changed.
The column_indices field indicates which columns are present in values.
Fields
column_indices: Vec<usize>Indices of columns that are included in this partial update (primary key columns + changed columns, sorted)
old_values: Vec<SqlValue>Old values for the included columns
new_values: Vec<SqlValue>New values for the included columns
Implementations