pub struct TransactionState {
pub id: u64,
pub active: bool,
/* private fields */
}Expand description
Transaction state for a session.
Tracks uncommitted changes during an active transaction, providing READ COMMITTED isolation when multiple sessions share a database.
Fields
id: u64Transaction ID (monotonically increasing)
active: boolWhether we’re in an active transaction block
Implementations
Sourceimpl TransactionState
impl TransactionState
Sourcepub fn record_insert(&mut self, table_name: String, row: Row)
pub fn record_insert(&mut self, table_name: String, row: Row)
Record an insert operation.
Sourcepub fn record_update(
&mut self,
table_name: String,
row_index: usize,
old_row: Row,
new_row: Row,
)
pub fn record_update( &mut self, table_name: String, row_index: usize, old_row: Row, new_row: Row, )
Record an update operation.
Sourcepub fn record_delete(&mut self, table_name: String, row_index: usize, row: Row)
pub fn record_delete(&mut self, table_name: String, row_index: usize, row: Row)
Record a delete operation.
Sourcepub fn record_create_table(&mut self, table_name: String)
pub fn record_create_table(&mut self, table_name: String)
Record a table creation.
Sourcepub fn record_drop_table(&mut self, table_name: String)
pub fn record_drop_table(&mut self, table_name: String)
Record a table drop.
Sourcepub fn record_create_index(&mut self, index_name: String, table_name: String)
pub fn record_create_index(&mut self, index_name: String, table_name: String)
Record an index creation.
Sourcepub fn record_drop_index(&mut self, index_name: String)
pub fn record_drop_index(&mut self, index_name: String)
Record an index drop.
Sourcepub fn get_inserted_rows(&self, table_name: &str) -> Option<&Vec<Row>>
pub fn get_inserted_rows(&self, table_name: &str) -> Option<&Vec<Row>>
Get rows inserted in this transaction for a table.
Sourcepub fn get_deleted_indices(&self, table_name: &str) -> Option<&Vec<usize>>
pub fn get_deleted_indices(&self, table_name: &str) -> Option<&Vec<usize>>
Get indices of rows deleted in this transaction for a table.
Sourcepub fn get_updated_rows(&self, table_name: &str) -> Option<&HashMap<usize, Row>>
pub fn get_updated_rows(&self, table_name: &str) -> Option<&HashMap<usize, Row>>
Get updated rows for a table (index -> new_row).
Sourcepub fn is_deleted(&self, table_name: &str, row_index: usize) -> bool
pub fn is_deleted(&self, table_name: &str, row_index: usize) -> bool
Check if a row at a given index was deleted in this transaction.
Sourcepub fn get_updated_row(
&self,
table_name: &str,
row_index: usize,
) -> Option<&Row>
pub fn get_updated_row( &self, table_name: &str, row_index: usize, ) -> Option<&Row>
Get the updated version of a row if it was updated in this transaction.
Sourcepub fn take_changes(self) -> Vec<TransactionChange>
pub fn take_changes(self) -> Vec<TransactionChange>
Consume the transaction state and return all changes for commit.
Sourcepub fn changes(&self) -> &[TransactionChange]
pub fn changes(&self) -> &[TransactionChange]
Get all changes (for inspection without consuming).
Sourcepub fn has_changes(&self) -> bool
pub fn has_changes(&self) -> bool
Check if there are any uncommitted changes.